@@ -186,11 +186,7 @@ initialize_web_extensions (WebKitWebContext *context)
     const gchar *local_path = gst_wpe_get_devenv_extension_path ();
     const gchar *path = g_file_test (local_path, G_FILE_TEST_IS_DIR) ? local_path : G_STRINGIFY (WPE_EXTENSION_INSTALL_DIR);
     GST_INFO ("Loading WebExtension from %s", path);
-#if USE_WPE2
-    webkit_web_context_set_web_process_extensions_directory (context, path);
-#else
     webkit_web_context_set_web_extensions_directory (context, path);
-#endif
 }
 
 static void
@@ -300,7 +296,6 @@ webkit_extension_msg_received (WebKitWebContext  *context,
     GVariant *params = webkit_user_message_get_parameters (message);
     gboolean res = TRUE;
 
-    GST_TRACE_OBJECT(src, "Handling message %s", name);
     if (!g_strcmp0(name, "gstwpe.new_stream")) {
         guint32 id = g_variant_get_uint32 (g_variant_get_child_value (params, 0));
         const gchar *capsstr = g_variant_get_string (g_variant_get_child_value (params, 1), NULL);
@@ -330,14 +325,6 @@ webkit_extension_msg_received (WebKitWebContext  *context,
         webkit_extension_gerror_msg_received (src, params);
     } else if (!g_strcmp0(name, "gstwpe.bus_message")) {
         webkit_extension_bus_message_received (src, params);
-    } else if (!g_strcmp0(name, "gstwpe.console_message")) {
-        const gchar *message = g_variant_get_string (g_variant_get_child_value (params, 0), NULL);
-        GstStructure *structure = gst_structure_new ("wpe-console-message",
-            "message", G_TYPE_STRING, message,
-            NULL);
-
-        gst_element_post_message(GST_ELEMENT(src), gst_message_new_custom(GST_MESSAGE_ELEMENT,
-            GST_OBJECT(src), structure));
     } else {
         res = FALSE;
         g_error("Unknown event: %s", name);
@@ -360,14 +347,10 @@ WPEView* WPEContextThread::createWPEView(GstWpeVideoSrc* src, GstGLContext* cont
     WPEView* view = nullptr;
     dispatch([&]() mutable {
         if (!glib.web_context) {
-#if USE_WPE2
-            glib.web_context = WEBKIT_WEB_CONTEXT(g_object_new(WEBKIT_TYPE_WEB_CONTEXT, nullptr));
-#else
-            auto *manager = webkit_website_data_manager_new(NULL);
+            auto *manager = webkit_website_data_manager_new_ephemeral();
             glib.web_context =
                 webkit_web_context_new_with_website_data_manager(manager);
             g_object_unref(manager);
-#endif
         }
         view = new WPEView(glib.web_context, src, context, display, width, height);
     });
@@ -401,7 +384,7 @@ static gboolean s_loadFailedWithTLSErrors(WebKitWebView*,  gchar* failing_uri, G
     return FALSE;
 }
 
-static void s_loadProgressChanged(GObject* object, GParamSpec*, gpointer data)
+static void s_loadProgressChaned(GObject* object, GParamSpec*, gpointer data)
 {
     GstElement* src = GST_ELEMENT_CAST (data);
     // The src element is locked already so we can't call
@@ -415,26 +398,7 @@ static void s_loadProgressChanged(GObject* object, GParamSpec*, gpointer data)
     gst_object_unref (bus);
 }
 
-static void s_webProcessCrashed(WebKitWebView*, WebKitWebProcessTerminationReason reason, gpointer data)
-{
-    auto &view = *static_cast<WPEView *>(data);
-    auto *src = view.src();
-    gchar *reason_str =
-        g_enum_to_string (WEBKIT_TYPE_WEB_PROCESS_TERMINATION_REASON, reason);
-
-    // In case the crash happened while doing the initial URL loading, unlock
-    // the load completion waiting.
-    view.notifyLoadFinished();
-
-    // TODO: Emit a signal here and fallback to error system if signal wasn't handled by application?
-
-    GST_ELEMENT_ERROR(GST_ELEMENT_CAST(src), RESOURCE, FAILED, (NULL), ("%s", reason_str));
-
-    g_free (reason_str);
-}
-
 WPEView::WPEView(WebKitWebContext* web_context, GstWpeVideoSrc* src, GstGLContext* context, GstGLDisplay* display, int width, int height)
-  : m_src(src)
 {
 #ifdef G_OS_UNIX
 {
@@ -442,11 +406,7 @@ WPEView::WPEView(WebKitWebContext* web_context, GstWpeVideoSrc* src, GstGLContex
 
         if (parent && GST_IS_WPE_SRC (parent)) {
             audio.init_ext_sigid = g_signal_connect (web_context,
-#if USE_WPE2
-                              "initialize-web-process-extensions",
-#else
                               "initialize-web-extensions",
-#endif
                               G_CALLBACK (initialize_web_extensions),
                               NULL);
             audio.extension_msg_sigid = g_signal_connect (web_context,
@@ -512,8 +472,7 @@ WPEView::WPEView(WebKitWebContext* web_context, GstWpeVideoSrc* src, GstGLContex
 
     g_signal_connect(webkit.view, "load-failed", G_CALLBACK(s_loadFailed), src);
     g_signal_connect(webkit.view, "load-failed-with-tls-errors", G_CALLBACK(s_loadFailedWithTLSErrors), src);
-    g_signal_connect(webkit.view, "notify::estimated-load-progress", G_CALLBACK(s_loadProgressChanged), src);
-    g_signal_connect(webkit.view, "web-process-terminated", G_CALLBACK(s_webProcessCrashed), this);
+    g_signal_connect(webkit.view, "notify::estimated-load-progress", G_CALLBACK(s_loadProgressChaned), src);
 
     auto* settings = webkit_web_view_get_settings(webkit.view);
     webkit_settings_set_enable_webaudio(settings, TRUE);
@@ -736,37 +695,6 @@ void WPEView::loadUri(const gchar* uri)
     });
 }
 
-static void s_runJavascriptFinished(GObject* object, GAsyncResult* result, gpointer user_data)
-{
-    GError *error = NULL;
-#if USE_WPE2
-    g_autoptr(JSCValue) js_result = webkit_web_view_evaluate_javascript_finish(
-#else
-    g_autoptr(WebKitJavascriptResult) js_result = webkit_web_view_run_javascript_finish(
-#endif
-        WEBKIT_WEB_VIEW(object), result, &error);
-
-    // TODO: Pass result back to signal call site using a GstPromise?
-    (void) js_result;
-
-    if (error) {
-        GST_WARNING("Error running javascript: %s", error->message);
-        g_error_free(error);
-    }
-}
-
-void WPEView::runJavascript(const char* script)
-{
-    s_view->dispatch([&]() {
-#if USE_WPE2
-        webkit_web_view_evaluate_javascript(webkit.view, script, -1, nullptr, nullptr, nullptr,
-                                            s_runJavascriptFinished, nullptr);
-#else
-        webkit_web_view_run_javascript(webkit.view, script, nullptr, s_runJavascriptFinished, nullptr);
-#endif
-    });
-}
-
 void WPEView::loadData(GBytes* bytes)
 {
     s_view->dispatch([this, bytes = g_bytes_ref(bytes)]() {
@@ -799,7 +727,7 @@ struct ImageContext {
 
 void WPEView::handleExportedImage(gpointer image)
 {
-    ImageContext* imageContext = g_new (ImageContext, 1);
+    ImageContext* imageContext = g_slice_new(ImageContext);
     imageContext->view = this;
     imageContext->image = static_cast<gpointer>(image);
     EGLImageKHR eglImage = wpe_fdo_egl_exported_image_get_egl_image(static_cast<struct wpe_fdo_egl_exported_image*>(image));
@@ -835,7 +763,7 @@ void WPEView::s_releaseSHMBuffer(gpointer data)
 {
     SHMBufferContext* context = static_cast<SHMBufferContext*>(data);
     context->view->releaseSHMBuffer(data);
-    g_free (context);
+    g_slice_free(SHMBufferContext, context);
 }
 
 void WPEView::handleExportedBuffer(struct wpe_fdo_shm_exported_buffer* buffer)
@@ -853,7 +781,7 @@ void WPEView::handleExportedBuffer(struct wpe_fdo_shm_exported_buffer* buffer)
     gsize size = width * height * 4;
     auto* data = static_cast<uint8_t*>(wl_shm_buffer_get_data(shmBuffer));
 
-    SHMBufferContext* bufferContext = g_new (SHMBufferContext, 1);
+    SHMBufferContext* bufferContext = g_slice_new(SHMBufferContext);
     bufferContext->view = this;
     bufferContext->buffer = buffer;
 
@@ -901,7 +829,7 @@ void WPEView::s_releaseImage(GstEGLImage* image, gpointer data)
 {
     ImageContext* context = static_cast<ImageContext*>(data);
     context->view->releaseImage(context->image);
-    g_free (context);
+    g_slice_free(ImageContext, context);
 }
 
 struct wpe_view_backend* WPEView::backend() const
@@ -929,10 +857,3 @@ void WPEView::dispatchAxisEvent(struct wpe_input_axis_event& wpe_event)
         wpe_view_backend_dispatch_axis_event(backend(), &wpe_event);
     });
 }
-
-void WPEView::dispatchTouchEvent(struct wpe_input_touch_event& wpe_event)
-{
-    s_view->dispatch([&]() {
-        wpe_view_backend_dispatch_touch_event(backend(), &wpe_event);
-    });
-}
