@@ -23,7 +23,6 @@
  * @title: GstVaDisplay
  * @short_description: Generic VADisplay wrapper.
  * @sources:
- * - gstva.h
  * - gstvadisplay.h
  *
  * It is a generic wrapper for VADisplay. To create new instances
@@ -42,8 +41,6 @@
 #endif
 
 #include "gstvadisplay.h"
-
-#include <stdio.h>              /* sscanf */
 #include <va/va.h>
 
 GST_DEBUG_CATEGORY (gst_va_display_debug);
@@ -52,15 +49,12 @@ GST_DEBUG_CATEGORY (gst_va_display_debug);
 typedef struct _GstVaDisplayPrivate GstVaDisplayPrivate;
 struct _GstVaDisplayPrivate
 {
+  GRecMutex lock;
   VADisplay display;
 
   gboolean foreign;
   gboolean init;
   GstVaImplementation impl;
-  gchar *vendor_desc;
-
-  guint driver_major;
-  guint driver_minor;
 };
 
 #define gst_va_display_parent_class parent_class
@@ -71,7 +65,6 @@ G_DEFINE_TYPE_WITH_CODE (GstVaDisplay, gst_va_display, GST_TYPE_OBJECT,
 enum
 {
   PROP_VA_DISPLAY = 1,
-  PROP_DESC,
   N_PROPERTIES
 };
 
@@ -92,82 +85,12 @@ _get_implementation (const char *vendor)
   return GST_VA_IMPLEMENTATION_OTHER;
 }
 
-static char *
-_get_desc (const char *vendor, GstVaImplementation impl)
-{
-  char *end, *start;
-  char desc[1024];
-  size_t size;
-
-  if (impl == GST_VA_IMPLEMENTATION_OTHER)
-    return g_strdup (vendor);
-
-  start = strstr (vendor, "for ");
-  if (!start)
-    return g_strdup (vendor);
-  start += 4;
-
-  switch (impl) {
-    case GST_VA_IMPLEMENTATION_MESA_GALLIUM:
-      end = strchr (start, '(');
-      break;
-    default:
-      end = strstr (start, "- ");
-      break;
-  }
-
-  if (!end)
-    return g_strdup (vendor);
-  end -= 1;
-
-  size = MIN (1024, end - start);
-  memcpy (desc, start, size);
-  desc[size] = '\0';
-  return g_strdup (desc);
-}
-
-static gboolean
-_get_driver_version (const char *vendor, GstVaImplementation impl,
-    guint * major, guint * minor)
-{
-  guint maj, min;
-
-  if (!vendor)
-    return FALSE;
-
-  switch (impl) {
-    case GST_VA_IMPLEMENTATION_MESA_GALLIUM:
-      if (sscanf (vendor, "Mesa Gallium driver %d.%d.", &maj, &min) == 2) {
-        *major = maj;
-        *minor = min;
-        return TRUE;
-      }
-      break;
-    case GST_VA_IMPLEMENTATION_INTEL_IHD:
-    case GST_VA_IMPLEMENTATION_INTEL_I965:{
-      char *end = strstr (vendor, " - ");
-      if (end && sscanf (end, " - %d.%d.", &maj, &min) == 2) {
-        *major = maj;
-        *minor = min;
-        return TRUE;
-      }
-      break;
-    }
-    default:
-      break;
-  }
-
-  return FALSE;
-}
-
 static gboolean
 _gst_va_display_filter_driver (GstVaDisplay * self, gpointer foreign_display)
 {
   GstVaDisplayPrivate *priv = GET_PRIV (self);
   VADisplay dpy;
   const char *vendor;
-  GstVaImplementation impl;
-  guint major, minor;
 
   g_assert ((foreign_display != NULL) ^ (priv->display != NULL));
   dpy = foreign_display ? foreign_display : priv->display;
@@ -175,24 +98,13 @@ _gst_va_display_filter_driver (GstVaDisplay * self, gpointer foreign_display)
   vendor = vaQueryVendorString (dpy);
   GST_INFO ("VA-API driver vendor: %s", vendor);
 
-  impl = _get_implementation (vendor);
+  /* XXX(victor): driver allow list */
 
   if (foreign_display) {
     priv->display = foreign_display;
     priv->foreign = TRUE;
-  } else {
-    if (g_getenv ("GST_VA_ALL_DRIVERS") == NULL
-        && impl == GST_VA_IMPLEMENTATION_OTHER) {
-      GST_WARNING_OBJECT (self, "Unsupported driver: %s", vendor);
-      return FALSE;
-    }
-  }
-  priv->impl = impl;
-  priv->vendor_desc = _get_desc (vendor, priv->impl);
-  if (_get_driver_version (vendor, priv->impl, &major, &minor)) {
-    priv->driver_major = major;
-    priv->driver_minor = minor;
   }
+  priv->impl = _get_implementation (vendor);
 
   return TRUE;
 }
@@ -214,7 +126,6 @@ gst_va_display_set_display (GstVaDisplay * self, gpointer display)
   /* assume driver is already initialized */
   priv->init = TRUE;
 
-  /* assumed that user knows what's doing so all drivers are allowed */
   _gst_va_display_filter_driver (self, display);
 }
 
@@ -246,9 +157,6 @@ gst_va_display_get_property (GObject * object, guint prop_id, GValue * value,
     case PROP_VA_DISPLAY:
       g_value_set_pointer (value, priv->display);
       break;
-    case PROP_DESC:
-      g_value_set_string (value, priv->vendor_desc);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -285,7 +193,7 @@ gst_va_display_finalize (GObject * object)
 {
   GstVaDisplayPrivate *priv = GET_PRIV (object);
 
-  g_free (priv->vendor_desc);
+  g_rec_mutex_clear (&priv->lock);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -305,11 +213,6 @@ gst_va_display_class_init (GstVaDisplayClass * klass)
       g_param_spec_pointer ("va-display", "VADisplay", "VA Display handler",
       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
-  g_properties[PROP_DESC] =
-      g_param_spec_string ("description", "Description",
-      "Vendor specific VA implementation description", NULL,
-      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
-
   g_object_class_install_properties (gobject_class, N_PROPERTIES, g_properties);
 }
 
@@ -318,9 +221,52 @@ gst_va_display_init (GstVaDisplay * self)
 {
   GstVaDisplayPrivate *priv = GET_PRIV (self);
 
+  g_rec_mutex_init (&priv->lock);
   priv->impl = GST_VA_IMPLEMENTATION_INVALID;
 }
 
+/**
+ * gst_va_display_lock:
+ * @self: a #GstVaDisplay
+ *
+ * Lock the display. It will be used before we call the
+ * VA API functions to serialize the VA commands.
+ *
+ * Since: 1.20
+ **/
+void
+gst_va_display_lock (GstVaDisplay * self)
+{
+  GstVaDisplayPrivate *priv;
+
+  g_return_if_fail (GST_IS_VA_DISPLAY (self));
+
+  priv = GET_PRIV (self);
+
+  g_rec_mutex_lock (&priv->lock);
+}
+
+/**
+ * gst_va_display_unlock:
+ * @self: a #GstVaDisplay
+ *
+ * Unlock the display. It will be used after we call the
+ * VA API functions.
+ *
+ * Since: 1.20
+ **/
+void
+gst_va_display_unlock (GstVaDisplay * self)
+{
+  GstVaDisplayPrivate *priv;
+
+  g_return_if_fail (GST_IS_VA_DISPLAY (self));
+
+  priv = GET_PRIV (self);
+
+  g_rec_mutex_unlock (&priv->lock);
+}
+
 #ifndef GST_DISABLE_GST_DEBUG
 static gchar *
 _strip_msg (const char *message)
@@ -425,12 +371,12 @@ gst_va_display_initialize (GstVaDisplay * self)
 gpointer
 gst_va_display_get_va_dpy (GstVaDisplay * self)
 {
-  GstVaDisplayPrivate *priv;
+  VADisplay dpy;
 
   g_return_val_if_fail (GST_IS_VA_DISPLAY (self), NULL);
-  priv = GET_PRIV (self);
 
-  return priv->display;
+  g_object_get (self, "va-display", &dpy, NULL);
+  return dpy;
 }
 
 /**
@@ -454,34 +400,3 @@ gst_va_display_get_implementation (GstVaDisplay * self)
   priv = GET_PRIV (self);
   return priv->impl;
 }
-
-/**
- * gst_va_display_check_version:
- * @self: a #GstVaDisplay
- * @major: major version to check
- * @minor: minor version to check
- *
- * Returns: whether driver version is equal or greater than @major.@minor
- *
- * Since: 1.24
- */
-gboolean
-gst_va_display_check_version (GstVaDisplay * self, guint major, guint minor)
-{
-  GstVaDisplayPrivate *priv;
-
-  g_return_val_if_fail (GST_IS_VA_DISPLAY (self), FALSE);
-
-  priv = GET_PRIV (self);
-
-  /* if cannot parse the version, all it's valid */
-  if (priv->driver_major == 0 && priv->driver_minor == 0)
-    return TRUE;
-
-  if (priv->driver_major < major)
-    return FALSE;
-  if (priv->driver_major == major && priv->driver_minor < minor)
-    return FALSE;
-
-  return TRUE;
-}
