@@ -309,15 +309,15 @@ serialize_next (GstRtmpChunkStream * cstream, guint32 chunk_size,
     case CHUNK_TYPE_0:
       /* SRSLY:  "Message stream ID is stored in little-endian format." */
       GST_WRITE_UINT32_LE (map.data + offset + 7, meta->mstream);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_1:
       GST_WRITE_UINT24_BE (map.data + offset + 3, meta->size);
       GST_WRITE_UINT8 (map.data + offset + 6, meta->type);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_2:
       GST_WRITE_UINT24_BE (map.data + offset,
           ext_ts ? 0xffffff : meta->ts_delta);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_3:
       offset += chunk_header_sizes[type];
 
@@ -325,7 +325,6 @@ serialize_next (GstRtmpChunkStream * cstream, guint32 chunk_size,
         GST_WRITE_UINT32_BE (map.data + offset, meta->ts_delta);
         offset += 4;
       }
-      break;
   }
 
   g_assert (offset == header_size);
@@ -463,14 +462,14 @@ gst_rtmp_chunk_stream_parse_header (GstRtmpChunkStream * cstream,
       has_abs_timestamp = TRUE;
       /* SRSLY:  "Message stream ID is stored in little-endian format." */
       meta->mstream = GST_READ_UINT32_LE (message_header + 7);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_1:
       meta->type = GST_READ_UINT8 (message_header + 6);
       meta->size = GST_READ_UINT24_BE (message_header + 3);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_2:
       meta->ts_delta = GST_READ_UINT24_BE (message_header);
-      /* FALLTHROUGH */
+      /* no break */
     case CHUNK_TYPE_3:
       if (needs_ext_ts (meta)) {
         guint32 timestamp;
@@ -492,7 +491,6 @@ gst_rtmp_chunk_stream_parse_header (GstRtmpChunkStream * cstream,
           header_size += 4;
         }
       }
-      break;
   }
 
   GST_MEMDUMP ("<<< chunk header", data, header_size);
@@ -692,7 +690,7 @@ gst_rtmp_chunk_streams_new (void)
 
   init_debug ();
 
-  cstreams = g_new (GstRtmpChunkStreams, 1);
+  cstreams = g_slice_new (GstRtmpChunkStreams);
   cstreams->array = g_array_new (FALSE, TRUE, sizeof (GstRtmpChunkStream));
   g_array_set_clear_func (cstreams->array,
       (GDestroyNotify) gst_rtmp_chunk_stream_clear);
@@ -704,7 +702,7 @@ gst_rtmp_chunk_streams_free (gpointer ptr)
 {
   GstRtmpChunkStreams *cstreams = ptr;
   g_clear_pointer (&cstreams->array, g_array_unref);
-  g_free (cstreams);
+  g_slice_free (GstRtmpChunkStreams, cstreams);
 }
 
 GstRtmpChunkStream *
