@@ -110,7 +110,7 @@ gst_zebra_stripe_class_init (GstZebraStripeClass * klass)
 
   gst_element_class_set_static_metadata (GST_ELEMENT_CLASS (klass),
       "Zebra stripe overlay",
-      "Video/Filter/Analyzer",
+      "Filter/Analysis",
       "Overlays zebra striping on overexposed areas of video",
       "David Schleef <ds@entropywave.com>");
 
