@@ -17,7 +17,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#pragma once
+#ifndef __GST_D3D11_AV1_DEC_H__
+#define __GST_D3D11_AV1_DEC_H__
 
 #include "gstd3d11decoder.h"
 
@@ -28,3 +29,5 @@ void  gst_d3d11_av1_dec_register (GstPlugin * plugin,
                                   guint rank);
 
 G_END_DECLS
+
+#endif /* __GST_D3D11_AV1_DEC_H__ */
